@@ -3,7 +3,7 @@ import os
 import sys
 
 app_name = 'primaryschool'
-app_version = '0.0.13'
+app_version = '0.0.15'
 app_author = 'larryw3i'
 app_author_email = 'larryw3i@163.com'
 app_maintainer = app_author
@@ -15,6 +15,10 @@ app_contributors = [
     '',
 ]
 
+app_sponsors = [
+    ''
+]
+
 install_prefix = 'python -m pip install '
 requirements = [
     # product
@@ -53,4 +57,3 @@ def get_requirements_product():
 def install_requirements_product():
     requirements_product = get_requirements_product()
     os.system(install_prefix + requirements_product)
-
