@@ -18,14 +18,15 @@ from primaryschool.resource import (default_font, default_font_path,
                                     get_default_font, get_font_path,
                                     get_resource_path)
 from primaryschool.subjects import *
-from primaryschool.subjects._templates_ import GameBase
-from primaryschool.subjects.yuwen.words import cn_ps_c
+from primaryschool.subjects._abc_ import GameBase
+from primaryschool.subjects.yuwen.words import cn_ps_c, cn_ps_c_bb
 
 # primaryschool.subjects.yuwen.g_pinyin_missile
 module_str = __name__
 
 name_t = _('Pinyin Missile')
 
+default_difficulty_index = 16
 difficulties = [
     _('Grade 1.1'),  # 0
     _('Grade 1.2'),  # 1
@@ -43,35 +44,68 @@ difficulties = [
     _('High level'),  # 13
     _('All grades'),  # 14
     _('All Chinese characters'),  # 15
+    _('Grade 1.1 (30 characters)'),  # 16
+    _('Grade 1.2 (30 characters)'),  # 17
+    _('Grade 2.1 (30 characters)'),  # 18
+    _('Grade 2.2 (30 characters)'),  # 19
+    _('Grade 3.1 (30 characters)'),  # 20
+    _('Grade 3.2 (30 characters)'),  # 21
+    _('Grade 4.1 (30 characters)'),  # 22
+    _('Grade 4.2 (30 characters)'),  # 23
+    _('Grade 5.1 (30 characters)'),  # 24
+    _('Grade 5.2 (30 characters)'),  # 25
+    _('Grade 6.1 (30 characters)'),  # 26
+    _('Grade 6.2 (30 characters)'),  # 27
+    _('Low level (30 characters)'),  # 28
+    _('High level (30 characters)'),  # 29
+    _('All grades (30 characters)'),  # 30
+    _('All Chinese characters (30 characters)'),  # 31
+
 ]
 
+help_t = _('''
+Enter the pinyin corresponding to the Chinese character, and enter the number
+after the pinyin to indicate the tone.
+''')
+
 pinyin = Pinyin()
 
+cn_ps_chars = cn_ps_c_bb
+
 
 class Word():
-
     def __init__(self, pm):
         self.pm = pm
-        self.win = self.pm.win
+        self.ps = self.pm.ps
         self.rand_word_count = 70
         pass
 
-    def get_words(self, g: int):
-        if g == 15:
-            return self.get_rand_words(self.rand_word_count)
-        if 0 <= g < 15:
-            return self.get_cn_ps_words(g)
+    def get_words(self, g_index: int):
+        _base_len = int(len(difficulties) / 2)
+        if g_index < _base_len:
+            if g_index == _base_len - 1:
+                return self.get_rand_words(self.rand_word_count)
+            if 0 <= g_index < _base_len - 1:
+                return self.get_cn_ps_words(g_index)
+        else:
+            g_index = g_index - _base_len
+            if g_index == _base_len - 1:
+                return random.choices(
+                    self.get_rand_words(self.rand_word_count), k=30)
+            if 0 <= g_index < _base_len - 1:
+                return random.choices(
+                    self.get_cn_ps_words(g_index), k=30)
 
-    def get_cn_ps_words(self, g: int):
+    def get_cn_ps_words(self, g_index: int):
         words = []
-        if g < 12:
-            words = cn_ps_c[g]
-        elif g == 12:
-            words = sum(cn_ps_c[0:6], [])
-        elif g == 13:
-            words = sum(cn_ps_c[6:16], [])
-        elif g == 14:
-            words = sum(cn_ps_c[0:16], [])
+        if g_index < 12:
+            words = cn_ps_chars[g_index]
+        elif g_index == 12:
+            words = sum(cn_ps_chars[0:6], [])
+        elif g_index == 13:
+            words = sum(cn_ps_chars[6:16], [])
+        elif g_index == 14:
+            words = sum(cn_ps_chars[0:16], [])
         return sum(words, [])
 
     def get_rand_words(self, n):
@@ -81,7 +115,7 @@ class Word():
 class Wave():
     def __init__(self, pm):
         self.pm = pm
-        self.win = self.pm.win
+        self.ps = self.pm.ps
         self.intercept_interval = \
             self.pm.wordsurfaces_manager.intercept_interval
         self.surface = self.pm.surface
@@ -115,40 +149,45 @@ class Wave():
 class InputSurface():
     def __init__(self, pm):
         self.pm = pm
-        self.win = self.pm.win
+        self.ps = self.pm.ps
         self.font_size = 55
         self.font = get_default_font(self.font_size)
-        self.font_color = (200, 22, 98)
+        self.surface_color = (200, 22, 98)
+        self.surface_bg_color = (200, 100, 100, 89)
+        self.surface_bg_border_radius = 10
+        self.surface_bg_width = 2
         self.surface = None
         self.frame_counter = 0
 
-        self.font.set_bold(True)
-
     def _update(self):
         self.surface = self.font.render(
-            self.pm._input, False, self.font_color)
+            self.pm._input, False, self.surface_color)
 
     def blit(self):
         if self.surface is None:
             return
         w, h = self.surface.get_size()
+        _dest = (self.pm.w_width_of_2 - w / 2, self.pm.w_height - h)
+        _surface_size = self.surface.get_size()
+        _bg_rect = (_dest[0], _dest[1], _surface_size[0], _surface_size[1])
+        pygame.draw.rect(self.pm.surface, color=self.surface_bg_color,
+                         width=self.surface_bg_width, rect=_bg_rect,
+                         border_radius=self.surface_bg_border_radius)
         self.pm.surface.blit(
-            self.surface,
-            (self.pm.w_width_of_2 - w / 2,
-             self.pm.w_height - h))
+            self.surface, _dest)
 
 
 class WallSurface():
     def __init__(self, pm):
         self.pm = pm
-        self.win = self.pm.win
+        self.ps = self.pm.ps
         self.h = self.pm.w_height / 20
         self.surface = pygame.Surface((self.pm.w_width, self.h))
         self.color = self.get_default_color()
         self.emitter_radius = self.h / 2
         self.emitter_color = None
         self.center = self.get_center()
-        self.flicker_interval = 1 * self.win.FPS  # 2s
+        self.flicker_interval = 1 * self.ps.FPS  # 2s
         self.flicker_counter = 0
         self.flicker_color = [self.color, (250, 0, 0)]
         self.flicker_color_step = (
@@ -191,13 +230,13 @@ class WallSurface():
         return self.emitter_color
 
     def get_center(self):
-        return [self.win.w_width_of_2, self.win.w_height - self.h / 2]
+        return [self.ps.w_width_of_2, self.ps.w_height - self.h / 2]
 
     def draw_emitter(self):
         self.emitter_color = self.set_emitter_color() \
             if self.pm.wordsurfaces_manager is None \
             else self.pm.wordsurfaces_manager.laser_color
-        pygame.draw.circle(self.win.surface, self.emitter_color,
+        pygame.draw.circle(self.ps.surface, self.emitter_color,
                            self.center, self.emitter_radius)
 
     def blit(self):
@@ -210,12 +249,12 @@ class WordSurfacesManager():
     def __init__(self, pm, frame_counter=0):
         self.pm = pm
         self.words = self.pm.words
-        self.win = self.pm.win
+        self.ps = self.pm.ps
         self.moving_surfaces = []
         self.frame_counter = frame_counter
-        self.interval = 2.2 * self.pm.FPS
+        self.interval = 3.5 * self.pm.FPS
         self.intercept_interval = 0.3 * self.pm.FPS
-        self.moving_speed = 0.8
+        self.moving_speed = 0.5
         self.intercepted_color = (175, 10, 175, 100)
         self.laser_color = (0, 0, 255, 90)
         self.laser_width = 2
@@ -310,11 +349,11 @@ class WordSurfacesManager():
 class InfoSurface():
     def __init__(self, pm):
         self.pm = pm
-        self.win = pm.win
-        self.surface = self.win.surface
+        self.ps = pm.ps
+        self.surface = self.ps.surface
         self.game_info_dest = (10, 10)
         self.game_info = name_t + \
-            '/' + difficulties[self.win.difficulty_index]
+            '/' + difficulties[self.ps.difficulty_index]
         self.game_info_color = (255, 0, 255, 10)
         self.font_size = 25
         self.font = get_default_font(self.font_size)
@@ -334,13 +373,13 @@ class InfoSurface():
 
         self.score = 0
         self._pass = False
-        self.win_info_surface = ...
+        self.win_info_surface = None
 
-        self.score_surface = ...
-        self.datetime_diff_surface = ...
-        self.greeting_surface = ...
+        self.score_surface = None
+        self.datetime_diff_surface = None
+        self.greeting_surface = None
 
-        self.end_time = self.win.end_time = None
+        self.end_time = self.ps.end_time = None
 
     def get_score_font_color(self):
         return (20, 255, 0) if self._pass else (255, 20, 0)
@@ -353,11 +392,11 @@ class InfoSurface():
 
     def get_win_info_dest(self):
         _w, _ = self.win_info_surface.get_size()
-        return [self.win.w_width - _w, 0]
+        return [self.ps.w_width - _w, 0]
 
     def get_datetime_diff_str(self):
         if self.end_time is None:
-            self.end_time = self.win.end_time = datetime.now()
+            self.end_time = self.ps.end_time = datetime.now()
         diff = (self.end_time - self.pm.start_time) + self.pm.last_timedelta
         _h, _rem = divmod(diff.seconds, 3600)
         _min, _sec = divmod(_rem, 60)
@@ -366,7 +405,6 @@ class InfoSurface():
     def blit(self):
         self.win_info_surface = self.font.render(
             self.get_win_info(), False, self.game_info_color)
-
         self.surface.blit(self.game_info_surface, self.game_info_dest)
         self.surface.blit(self.win_info_surface, self.get_win_info_dest())
 
@@ -389,22 +427,22 @@ class InfoSurface():
         _w, _h = self.greeting_surface.get_size()
         _, _s_h = self.score_surface.get_size()
         return [
-            self.win.w_width_of_2 - _w / 2,
-            self.win.w_height_of_2 - _h - _s_h
+            self.ps.w_width_of_2 - _w / 2,
+            self.ps.w_height_of_2 - _h - _s_h
         ]
 
     def get_score_surface_dest(self):
         _w, _h = self.score_surface.get_size()
         return [
-            self.win.w_width_of_2 - _w / 2,
-            self.win.w_height_of_2 - _h
+            self.ps.w_width_of_2 - _w / 2,
+            self.ps.w_height_of_2 - _h
         ]
 
     def get_datetime_diff_surface_dest(self):
         _w, _h = self.datetime_diff_surface.get_size()
         return [
-            self.win.w_width_of_2 - _w / 2,
-            self.win.w_height_of_2 + _h
+            self.ps.w_width_of_2 - _w / 2,
+            self.ps.w_height_of_2 + _h
         ]
 
     def score_blit(self):
@@ -443,7 +481,7 @@ class InfoSurface():
 class WordSurface():
     def __init__(self, pm, _manager, word, dest=None):
         self.pm = pm
-        self.win = self.pm.win
+        self.ps = self.pm.ps
         self.manager = _manager
         self.wall_surface = None
         self.word = word
@@ -455,7 +493,6 @@ class WordSurface():
         self.intercept_frame_counter = 0
         self.laser_color = self.manager.laser_color
         self.laser_width = self.manager.laser_width
-
         self.surface = self.get_surface()
         self.size = self.get_size()
         self.dest = dest if dest else self.get_random_dest()
@@ -512,7 +549,7 @@ class WordSurface():
 
     def draw_bg(self):
         pygame.draw.polygon(
-            self.win.surface,
+            self.ps.surface,
             self.get_bg_color(),
             self.get_bg_points())
 
@@ -536,9 +573,9 @@ class WordSurface():
         return self.size[1]
 
     def add_dest(self, _add, blit=False):
-        if self.dest[0] < self.win.w_width:
+        if self.dest[0] < self.ps.w_width:
             self.dest[0] += _add[0]
-        if self.dest[1] < self.win.w_height:
+        if self.dest[1] < self.ps.w_height:
             self.dest[1] += _add[1]
         self.center = self.get_center()
         if blit:
@@ -553,9 +590,8 @@ class WordSurface():
     def draw_laser_line(self):
         if self.wall_surface is None:
             self.wall_surface = self.pm.wall_surface
-        assert self.wall_surface is not None
         pygame.draw.line(
-            self.win.surface, self.laser_color,
+            self.ps.surface, self.laser_color,
             self.wall_surface.center, self.center,
             self.laser_width)
 
@@ -601,26 +637,26 @@ class WordSurface():
 
 
 class PinyinMissile(GameBase):
-    def __init__(self, win):
-        self.win = win
+    def __init__(self, ps):
+        self.ps = ps
         # window
-        self.w_width = self.win.w_width
-        self.w_height = self.win.w_height
-        self.w_height_of_2 = self.win.w_height_of_2
-        self.w_width_of_2 = self.win.w_width_of_2
-        self.w_centrex_y = self.win.w_centrex_y
+        self.w_width = self.ps.w_width
+        self.w_height = self.ps.w_height
+        self.w_height_of_2 = self.ps.w_height_of_2
+        self.w_width_of_2 = self.ps.w_width_of_2
+        self.w_centrex_y = self.ps.w_centrex_y
         self.running = True
-        self.FPS = self.win.FPS
-        self.clock = self.win.clock
+        self.FPS = self.ps.FPS
+        self.clock = self.ps.clock
         self._load = False
-        self.subject = self.win.subject
-        self.subject_index = self.win.subject_index
-        self.subject_game_index = self.win.subject_game_index
-        self.difficulty_index = self.win.difficulty_index
-        self.main_menu = self.win.main_menu
-        self.play_menu = self.win.play_menu
-        self.save_menu = self.win.save_menu
-        self.surface = self.win.surface
+        self.subject = self.ps.subject
+        self.subject_index = self.ps.subject_index
+        self.subject_game_index = self.ps.subject_game_index
+        self.difficulty_index = self.ps.difficulty_index
+        self.main_menu = self.ps.main_menu
+        self.play_menu = self.ps.play_menu
+        self.save_menu = self.ps.save_menu
+        self.surface = self.ps.surface
         self._input = ''
         self.font = get_default_font(45)
         self.info_surface = InfoSurface(self)
@@ -717,6 +753,7 @@ class PinyinMissile(GameBase):
     def play(self):
         self._load = False
         self.wordsurfaces_manager.surfaces = []
+        self.wordsurfaces_manager.moving_surfaces = []
         self.wordsurfaces_manager.set_surfaces()
         self.start()
 
@@ -741,5 +778,5 @@ class PinyinMissile(GameBase):
             pygame.display.update()
 
 
-def enjoy(win):
-    return PinyinMissile(win)
+def enjoy(ps):
+    return PinyinMissile(ps)
